# Foo

## Living Standard, 1 January 1970

This version:
  http://example.com/foo
Editor:
  Example Editor

COPYRIGHT GOES HERE

## Abstract

Test algorithm auto-naming.

## 1. Find a Foo

Blah blah blah, foo

### 1.1. bar

foo

## 2. More Stuff

find more foo

foo

foo
find even more foo but also find some bar

foo

## Index

### Terms defined by this specification

- find even more foo, in §2
- find more foo, in §2
- find some bar, in §2